AddressSet

Trait AddressSet 

pub trait AddressSet {
    // Required method
    fn contains(&self, address: &Address) -> bool;
}
A set of Addresses that can be checked for membership.

Required Methods

fn contains(&self, address: &Address) -> bool

Returns true if the set contains the given address.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl AddressSet for BTreeSet<Address>

Source

fn contains(&self, address: &Address) -> bool

Source

impl<S: BuildHasher> AddressSet for HashSet<Address, S>

Available on crate feature std only.
Source

fn contains(&self, address: &Address) -> bool

Source

impl<T: AddressSet> AddressSet for &T

Source

fn contains(&self, address: &Address) -> bool

Source

impl<T: AddressSet> AddressSet for Option<T>

Source

fn contains(&self, address: &Address) -> bool

Implementors