TransactionConfig

Struct TransactionConfig 

pub struct TransactionConfig {
    pub priority_fee: Option<u64>,
    pub compute_unit_limit: Option<u32>,
    pub loaded_accounts_data_size_limit: Option<u32>,
    pub heap_size: Option<u32>,
}
Available on non-target_os=solana only.
Compute budget configuration for V1 transactions.

Fields

priority_fee: Option<u64>

Priority fee in lamports.

compute_unit_limit: Option<u32>

Maximum compute units. None means use 0.

loaded_accounts_data_size_limit: Option<u32>

Maximum bytes of account data that may be loaded. None means use 0.

heap_size: Option<u32>

Heap size in bytes. Must be multiple of 1024. None = 32KB.

Implementations

Source

impl TransactionConfig

pub const fn empty() -> Self

pub const fn with_priority_fee(self, fee: u64) -> Self

pub const fn with_compute_unit_limit(self, limit: u32) -> Self

pub const fn with_loaded_accounts_data_size_limit(self, limit: u32) -> Self

pub const fn with_heap_size(self, size: u32) -> Self

Heap size must be a multiple of 1024. Validated during deserialization.

pub const fn size(&self) -> usize

Total size in bytes required to store the config values.