TransactionConfigMask

Struct TransactionConfigMask 

pub struct TransactionConfigMask(pub u32);
Available on non-target_os=solana only.
Bitmask indicating which configuration values are present in a V1 transaction.

Each bit (or bit pair) corresponds to a specific configuration field. The config values array contains entries only for fields whose bits are set.

Tuple Fields

0: u32

Implementations

Source

impl TransactionConfigMask

pub const PRIORITY_FEE: u32 = 0b11

Mask for priority fee config.

Bits 0-1 (requires both bits set, 8 bytes as u64 LE).

pub const COMPUTE_UNIT_LIMIT: u32 = 0b100

Mask for compute unit limit

Bit 2 (4 bytes as u32 LE).

pub const LOADED_ACCOUNTS_DATA_SIZE: u32 = 0b1000

Mask for loaded accounts data size limit

Bit 3 (4 bytes as u32 LE).

pub const HEAP_SIZE: u32 = 0b10000

Mask for requested heap size.

Bit 4 (4 bytes as u32 LE).

pub const KNOWN_BITS: u32

Mask of all known/supported bits (bits 0-4).

pub const fn new(mask: u32) -> Self

pub const fn has_unknown_bits(&self) -> bool

Returns `true`` if any unknown bits are set.

An unknown bit is any bit that is not defined in KNOWN_BITS.

pub const fn has_priority_fee(&self) -> bool

pub const fn has_invalid_priority_fee_bits(&self) -> bool

Returns true if only one of the two priority fee bits is set (invalid).

pub const fn has_compute_unit_limit(&self) -> bool

pub const fn has_loaded_accounts_data_size(&self) -> bool

pub const fn has_heap_size(&self) -> bool

pub const fn size_of_config(&self) -> usize

Total size in bytes required to store the config values.