#[repr(C)]pub struct WireInstructionHeader {
pub program_id_index: u8,
pub num_accounts: u8,
pub data_len: [u8; 2],
}Fields
program_id_index: u8num_accounts: u8data_len: [u8; 2]Trait Implementations
Sourceimpl<'de, WincodeConfig: Config> SchemaRead<'de, WincodeConfig> for WireInstructionHeader
impl<'de, WincodeConfig: Config> SchemaRead<'de, WincodeConfig> for WireInstructionHeader
type Dst = WireInstructionHeader
Sourcefn read(
reader: impl Reader<'de>,
dst: &mut MaybeUninit<Self::Dst>,
) -> ReadResult<()>
fn read( reader: impl Reader<'de>, dst: &mut MaybeUninit<Self::Dst>, ) -> ReadResult<()>
Sourceimpl<WincodeConfig: Config> SchemaWrite<WincodeConfig> for WireInstructionHeader
impl<WincodeConfig: Config> SchemaWrite<WincodeConfig> for WireInstructionHeader
Sourceimpl<WincodeConfig: Config> ZeroCopy<WincodeConfig> for WireInstructionHeader
impl<WincodeConfig: Config> ZeroCopy<WincodeConfig> for WireInstructionHeader
Sourcefn from_bytes<'de>(bytes: &'de [u8], config: C) -> Result<&'de Self, ReadError>where
Self: Sized + SchemaRead<'de, C, Dst = Self>,
fn from_bytes<'de>(bytes: &'de [u8], config: C) -> Result<&'de Self, ReadError>where
Self: Sized + SchemaRead<'de, C, Dst = Self>,
Like
crate::ZeroCopy::from_bytes, but allows the caller to provide a custom configuration.Sourcefn from_bytes_mut<'de>(
bytes: &'de mut [u8],
config: C,
) -> Result<&'de mut Self, ReadError>where
Self: Sized + SchemaRead<'de, C, Dst = Self>,
fn from_bytes_mut<'de>(
bytes: &'de mut [u8],
config: C,
) -> Result<&'de mut Self, ReadError>where
Self: Sized + SchemaRead<'de, C, Dst = Self>,
Like
crate::ZeroCopy::from_bytes_mut, but allows the caller to provide a custom configuration.Auto Trait Implementations
impl Freeze for WireInstructionHeader
impl RefUnwindSafe for WireInstructionHeader
impl Send for WireInstructionHeader
impl Sync for WireInstructionHeader
impl Unpin for WireInstructionHeader
impl UnsafeUnpin for WireInstructionHeader
impl UnwindSafe for WireInstructionHeader